@@ -13,9 +13,10 @@ function(DATA,DATA_is_dist=TRUE,method="euclidean",DESIGN=NULL,make_design_nomin
 		D <- D.MW$D #already squared from the above function.
 		MW <- D.MW$MW		
 	}
-	S <- mdsTransform(D,MW)
+	#S <- mdsTransform(D,MW)
+	#res <- coreMDS(S,MW$M,k=k)
 	
-	res <- coreMDS(S,MW$M,k=k)
+	res <- coreMDS(D,MW$M,k=k)
 	#overwrite res with half of res because it's MDS and we don't care
 	res <- list(fi=res$fi,di=res$di,ci=res$ci,ri=res$ri,t=res$t,eigs=res$eigs,pdq=res$pdq,M=res$masses,X=res$X,D=D)
 	class(res) <- c("epMDS","list")
