@@ -9,7 +9,7 @@ function (x,...) {
   cat ("The analysis was performed on ", nrow(res.epPCA$fi),
        "individuals, described by", nrow(res.epPCA$fj), "variables\n")
   cat("*The results are available in the following objects:\n\n")
-  res <- array("", c(12, 2), list(1:12, c("name", "description")))
+  res <- array("", c(16, 2), list(1:16, c("name", "description")))
   
   res[1,] <- c("$fi","Factor scores of the rows")
   res[2,] <- c("$di","Squared distances of the rows")
@@ -22,8 +22,12 @@ function (x,...) {
   res[9,] <- c("$t","Explained Variance")
   res[10,] <- c("$eigs","Eigenvalues")  
   res[11,] <- c("$pdq","SVD data")
-  res[12,] <- c("$X","X matrix to decompose")  
-  
+  res[12,] <- c("$X","X matrix to decompose") 
+  res[13,] <- c("$M","Masses - each set to 1")  
+  res[14,] <- c("$W","Weights - each set to 1")
+  res[15,] <- c("$center","Center of X") 
+  res[16,] <- c("$scale","Scale factor of X")   
+    
   print(res)
 
 }
