@@ -17,9 +17,11 @@ supplementalProjection <- function(sup.transform=NULL,f.scores=NULL,Dv=NULL,scal
 	if(!is.null(scale.factor)){		
 		f.out <- f.out * matrix(scale.factor,nrow(f.out),ncol(f.scores),byrow=TRUE)
 	}
+	
+	##can be replaced by the fcdr.helper
 	f.out <- replace(f.out,is.nan(f.out),0)
 	d.out <- rowSums(f.out^2)
-	r.out <- repmat((1/d.out),1,length(Dv)) * (f.out^2)
+	r.out <- matrix(1/d.out,nrow(f.out),ncol(f.out)) * (f.out^2)
 	r.out <- replace(r.out,is.nan(r.out),0)
 	d.out <- as.matrix(d.out)
 	return(list(f.out=f.out,d.out=d.out,r.out=r.out))
